import React from 'react';
import Panel from './panel';
import { ComponentStory, Meta } from '@storybook/react';
import { configureStore } from '@reduxjs/toolkit';
import { colorPaletteConfigSlice } from '@graphpolaris/shared/lib/data-access/store';
import { Provider } from 'react-redux';
import { GraphPolarisThemeProvider } from '@graphpolaris/shared/lib/data-access/theme';

const Component: Meta<typeof Panel> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Panel',
  component: Panel,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <GraphPolarisThemeProvider>{story()}</GraphPolarisThemeProvider>
      </Provider>
    ),
  ],
};

// A super-simple mock of a redux store
const Mockstore = configureStore({
  reducer: {
    colorPaletteConfig: colorPaletteConfigSlice.reducer,
  },
});

const Template: ComponentStory<typeof Panel> = (args) => <Panel {...args} />;

export const Primary = Template.bind({});

Primary.args = {
  content: 'Testing header #1',
  color: 'blue',
};

export const Secondary = Template.bind({});

Secondary.args = {
  content: 'Testing header number twoooo',
  color: 'purple',
  children: <h1>I AM A CHILD</h1>,
};

export default Component;
