import React from 'react';
import { Meta } from '@storybook/react';
import { Provider } from 'react-redux';
import {
  colorPaletteConfigSlice,
  graphQueryResultSlice,
  querybuilderSlice,
  schemaSlice,
  setQuerybuilderNodes,
  setSchema,
  store,
} from '@graphpolaris/shared/lib/data-access/store';
import { GraphPolarisThemeProvider } from '@graphpolaris/shared/lib/data-access/theme';
import { SchemaUtils } from '@graphpolaris/shared/lib/schema/schema-utils';
import { Schema } from '@graphpolaris/shared/lib/schema/panel';
import { movieSchemaRaw } from '@graphpolaris/shared/lib/mock-data';
import { QueryBuilder } from '@graphpolaris/shared/lib/querybuilder';
import { configureStore } from '@reduxjs/toolkit';
import { configSlice } from '@graphpolaris/shared/lib/data-access/store/configSlice';
import { QueryGraph } from '@graphpolaris/shared/lib/querybuilder/model/graphology/model';
import { MultiGraph } from 'graphology';
import { QueryMultiGraphology } from '@graphpolaris/shared/lib/querybuilder/model/graphology/utils';

const SchemaAndQueryBuilder = () => {
  return (
    <div
      style={{
        display: 'flex',
        height: '100%',
        flexDirection: 'row',
        width: '100%',
        columnGap: '20px',
      }}
    >
      <div style={{ width: '100%', height: '100%' }}>
        <Schema />
      </div>
      <div style={{ width: '100%', height: '100%' }}>
        <QueryBuilder />
      </div>
    </div>
  );
};

const Component: Meta = {
  component: SchemaAndQueryBuilder,
  title: 'Panel',
  decorators: [
    // using the real store here
    (story) => (
      <Provider store={store}>
        <GraphPolarisThemeProvider>
          <div
            style={{
              width: '100%',
              height: '95vh',
            }}
          >
            {story()}
          </div>
        </GraphPolarisThemeProvider>
      </Provider>
    ),
  ],
};

export const SchemaAndQueryBuilderInteractivity = {
  play: async () => {
    const dispatch = store.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(movieSchemaRaw);

    const graph = new QueryMultiGraphology();
    dispatch(setQuerybuilderNodes(graph.export()));
    dispatch(setSchema(schema.export()));
  },
};

export default Component;
