import React from 'react';
import NodeLinkMap from './NodeLinkMap';
import { Provider } from 'react-redux';
import { configureStore } from '@reduxjs/toolkit';
import { GraphPolarisThemeProvider } from '../../data-access/theme';
import {
  colorPaletteConfigSlice,
  graphQueryResultSlice,
  assignNewGraphQueryResult,
} from '../../data-access/store';
import { flights } from './mock-data';

const Mockstore = configureStore({
  reducer: {
    colorPaletteConfig: colorPaletteConfigSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

export default {
  title: 'Components/Visualizations/GeospatialKG',
  component: NodeLinkMap,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <GraphPolarisThemeProvider>
          <div
            style={{
              width: '100%',
              height: '100vh',
            }}
          >
            {story()}
          </div>
        </GraphPolarisThemeProvider>
      </Provider>
    ),
  ],
};

const Template = (args) => <NodeLinkMap {...args} />;

export const Flights = Template.bind({});
Flights.args = {
  isAggregated: true,
  isFanned: true,
};
Flights.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(assignNewGraphQueryResult(flights));
};

export const FlightsAggregated = Template.bind({});
FlightsAggregated.args = {
  nodelink: 'faceting',
  isAggregated: true,
  isFanned: true,
};
FlightsAggregated.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(assignNewGraphQueryResult(flights));
};

export const FlightsClustered = Template.bind({});
FlightsClustered.args = {
  nodelink: 'cluster',
  isAggregated: false,
  isFanned: true,
};
FlightsClustered.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(assignNewGraphQueryResult(flights));
};
