/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { TileLayer, BitmapLayer } from 'deck.gl';
import { mapTypes } from '../config';

export const generateBaseLayer = (mapType: number) => {
  /**
   * Generates base layer on which the node-link will be visualized
   * Uses deck gl layers in combination with the openstreetmap api
   * Inspiration from: https://github.com/visgl/deck.gl/tree/8.9-release/examples/website/map-tile
   */

  const urls: string[] = mapTypes[Object.keys(mapTypes)[mapType]];

  return new TileLayer({
    data: urls,
    minZoom: 0,
    maxZoom: 19,
    tileSize: 256,

    renderSubLayers: (props) => {
      const {
        bbox: { west, south, east, north },
      } = props.tile;

      return new BitmapLayer(props, {
        data: null,
        image: props.data,
        bounds: [west, south, east, north],
      });
    },
  });
};
