/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { Graph, Viewport, Coordinates } from './types';

export const calcMaxWidth = (viewport: Viewport): number => {
  const vpBounds: number[] = viewport.getBounds();
  return Math.sqrt(
    Math.pow(vpBounds[0] - vpBounds[2], 2) +
      Math.pow(vpBounds[1] - vpBounds[3], 2)
  );
};

export const getColor = (prediction, colorScale): [number, number, number] => {
  return colorScale(prediction)
    .replace(/[^\d,]/g, '')
    .split(',')
    .map(Number);
};

export const calcAverageCoordinates = (
  lat: number[],
  long: number[]
): [number, number] => {
  return [
    lat.reduce((p, c) => p + c, 0) / lat.length,
    long.reduce((p, c) => p + c, 0) / long.length,
  ];
};

export const calcNodeDistance = (
  source: Coordinates,
  target: Coordinates
): number => {
  return Math.sqrt(
    Math.pow(source[0] - target[0], 2) + Math.pow(source[1] - target[1], 2)
  );
};

export const getInitialViewState = (
  graph: Graph,
  coordinate_path: string = 'attributes.coordinates'
): { [key: string]: number } => {
  const coordinates: Coordinates[] = graph.nodes.map((node) =>
    eval(`node.${coordinate_path}`)
  );

  const viewBounds: { [key: string]: number } = {
    minLong: coordinates[0][0],
    maxLong: coordinates[0][0],
    minLat: coordinates[0][1],
    maxLat: coordinates[0][1],
  };

  for (let i = 1; i < coordinates.length; i++) {
    const location: Coordinates = coordinates[i];
    viewBounds.minLong = Math.min(viewBounds.minLong, location[0]);
    viewBounds.maxLong = Math.max(viewBounds.maxLong, location[0]);
    viewBounds.minLat = Math.min(viewBounds.minLat, location[1]);
    viewBounds.maxLat = Math.max(viewBounds.maxLat, location[1]);
  }

  const middleLat: number = (viewBounds.minLat + viewBounds.maxLat) / 2;
  const middleLong: number = (viewBounds.minLong + viewBounds.maxLong) / 2;

  const maxSpan: number = Math.max(
    viewBounds.maxLong - viewBounds.minLong,
    viewBounds.maxLat - viewBounds.minLat
  );

  const optimalZoom: number = Math.min(20, 20 * (maxSpan / 360)) - 3;

  return {
    latitude: middleLat,
    longitude: middleLong,
    zoom: optimalZoom,
  };
};

export const getKeys = (
  graph,
  prefix = '',
  paths = { nodes: new Set(), edges: new Set() }
) => {
  for (const key in graph) {
    if (typeof graph[key] === 'object' && graph[key] !== null) {
      if (Array.isArray(graph[key])) {
        const newPrefix = prefix ? `${prefix}.${key}` : key;
        for (let i = 0; i < graph[key].length; i++) {
          getKeys(graph[key][i], newPrefix, paths);
        }
      } else {
        const newPrefix = prefix ? `${prefix}.${key}` : key;
        getKeys(graph[key], newPrefix, paths);
      }
    } else {
      const path = prefix ? `${prefix}.${key}` : key;
      if (prefix.startsWith('nodes')) {
        paths.nodes.add(path);
      } else if (prefix.startsWith('edges')) {
        paths.edges.add(path);
      }
    }
  }
  return paths;
};
