/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

/* istanbul ignore file */
/* The comment above was added so the code coverage wouldn't count this file towards code coverage.
 * We do not test components/renderfunctions/styling files.
 * See testing plan for more details.*/

import { select } from 'd3';
import React, { useEffect, useRef } from 'react';

type RowLabelColumnProps = {
  onMouseEnter: (row: number) => void;
  onMouseLeave: (row: number) => void;

  titles: string[];
  width: number;
  rowHeight: number;
  yOffset: number;
};
export const RowLabelColumn = (props: RowLabelColumnProps) => {
  const titleRows = props.titles.map((title, i) => (
    <RowLabel
      key={i}
      index={i}
      title={title}
      width={props.width}
      rowHeight={props.rowHeight}
      yOffset={props.yOffset}
      onMouseEnter={props.onMouseEnter}
      onMouseLeave={props.onMouseLeave}
    />
  ));

  return <g>{titleRows}</g>;
}

type RowLabelProps = {
  onMouseEnter: (row: number) => void;
  onMouseLeave: (row: number) => void;

  title: string;
  width: number;
  rowHeight: number;
  index: number;
  yOffset: number;
};

const RowLabel = (props: RowLabelProps) => {
  const ref = useRef<SVGGElement>(null);

  useEffect(() => {
    if (ref.current === null) return;
    select(ref.current)
      .on('mouseover', () => props.onMouseEnter(props.index))
      .on('mouseout', () => props.onMouseLeave(props.index));
  }, [ref.current]);

  return (
    <g
      ref={ref}
      className={'row-' + props.index}
      transform={
        'translate(0,' +
        (props.yOffset + props.rowHeight + props.index * props.rowHeight) +
        ')'
      }
    >
      <rect
        width={props.width}
        height={props.rowHeight}
        fill={props.index % 2 === 0 ? '#e6e6e6' : '#f5f5f5'}
      ></rect>
      <text x="10" y={props.rowHeight / 2} dy=".35em" style={{ fontWeight: 600 }}>
        {props.title}
      </text>
    </g>
  );
}
