import {
  assignNewGraphQueryResult,
  colorPaletteConfigSlice,
  graphQueryResultSlice,
  schemaSlice,
  setSchema,
} from "../../data-access/store";
import { GraphPolarisThemeProvider } from "../../data-access/theme";
import { configureStore } from "@reduxjs/toolkit";
import { Meta, ComponentStory } from "@storybook/react";
import { Provider } from "react-redux";

import Paohvis from "./paohvis";
import { SchemaUtils } from "../../schema/schema-utils";
import { bigMockQueryResults, simpleSchemaRaw, smallFlightsQueryResults } from "../../mock-data";
import { simpleSchemaAirportRaw } from "../../mock-data/schema/simpleAirportRaw";

const Component: Meta<typeof Paohvis> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: "Components/Visualizations/Paohvis",
  component: Paohvis,
  decorators: [
    (story) => (
      <div
        style={{
          width: '80%',
          height: '80vh',
        }}
      >
        <Provider store={Mockstore}>
          <GraphPolarisThemeProvider>
            {story()}
          </GraphPolarisThemeProvider>
        </Provider>
      </div>
    ),
  ],
};

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    colorPaletteConfig: colorPaletteConfigSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

export const TestWithData = {
  args: {
    loading: false,
    rowHeight: 50,
    hyperedgeColumnWidth: 50,
    gapBetweenRanges: 10,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology({
      nodes: [
        {
          name: '1',
          attributes: [{ name: 'a', type: 'string' }],
        },
      ],
      edges: [
        {
          name: '12', from: '1', to: '1', collection: '1c', attributes: [{ name: 'a', type: 'string' }],
        },
      ],
    });

    dispatch(setSchema(schema.export()));
    dispatch(
      assignNewGraphQueryResult({
        nodes: [
          { id: '1/a', attributes: { a: 's1' } },
          { id: '1/b1', attributes: { a: 's1' } },
          { id: '1/b2', attributes: { a: 's1' } },
          { id: '1/b3', attributes: { a: 's1' } },
        ],
        edges: [
          { id: '1c/z1', from: '1/b1', to: '1/a', attributes: { a: 's1' } },
          // { from: 'b2', to: 'a', attributes: {} },
          // { from: 'b3', to: 'a', attributes: {} },
          { id: '1c/z1', from: '1/a', to: '1/b1', attributes: { a: 's1' } },
        ],
      })
    )
  }
}

export const TestWithAirportSimple = {
  args: {
    loading: false,
    rowHeight: 50,
    hyperedgeColumnWidth: 50,
    gapBetweenRanges: 10,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaRaw);

    dispatch(setSchema(schema.export()));
    dispatch(
      assignNewGraphQueryResult(smallFlightsQueryResults)
    )
  }
}

export const TestWithAirport = {
  args: {
    loading: false,
    rowHeight: 50,
    hyperedgeColumnWidth: 50,
    gapBetweenRanges: 10,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaAirportRaw);

    dispatch(setSchema(schema.export()));
    dispatch(
      assignNewGraphQueryResult(bigMockQueryResults)
    )
  }
}

export default Component;
